==> gnome-do-plugins_0.8.2.1+dfsg.orig.tar.gz: gnome-do-plugins-0.8.2.1/AptURL/src/AptUrl.cs <==
/* AptUrl.cs 
 *
 * GNOME Do is the legal property of its developers. Please refer to the
 * COPYRIGHT file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Linq;
using System.Collections.Generic;

using Do.Universe;

namespace AptURL {

    public class AptAction : Act {

        public override string Name {
            get { return "Install";  }
        }

        public override string Description {
            get { return "Use apturl to install a package"; }
        }

        public override string Icon {
            get { return "update-manager"; }
        }

        public override IEnumerable<Type> SupportedItemTypes {
            get {
                return new Type[] {
                    typeof(ITextItem)
                };
            }
        }

        public override IEnumerable<Item> Perform (IEnumerable<Item> items, IEnumerable<Item> modItems)
        {
            string package = (items.First () as ITextItem).Text;

            System.Diagnostics.Process.Start ("apturl apt:" + package);
            return null;
        }
    }
}

==> gnome-do-plugins_0.8.5.orig.tar.gz: gnome-do-plugins-0.8.5/AptURL/src/AptUrl.cs <==
/* AptUrl.cs 
 *
 * GNOME Do is the legal property of its developers. Please refer to the
 * COPYRIGHT file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Linq;
using System.Collections.Generic;

using Do.Universe;

namespace AptURL {

    public class AptAction : Act {

        public override string Name {
            get { return "Install";  }
        }

        public override string Description {
            get { return "Use apturl to install a package"; }
        }

        public override string Icon {
            get { return "update-manager"; }
        }

        public override IEnumerable<Type> SupportedItemTypes {
            get {
                return new Type[] {
                    typeof(ITextItem)
                };
            }
        }

        public override IEnumerable<Item> Perform (IEnumerable<Item> items, IEnumerable<Item> modItems)
        {
            string package = (items.First () as ITextItem).Text;

            System.Diagnostics.Process.Start ("apturl", "apt:" + package);
            return null;
        }
    }
}
